/*
	msettingsdialog.h - settings dialog
	Copyright (C) 2003  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __MSETTINGSDIALOG_H__
#define __MSETTINGSDIALOG_H__

#include "mmainwindow.h"

#include <qlistview.h>

#include <kdialogbase.h>
#include <knuminput.h>
#include <kurlrequester.h>

// defaults:

// general
#define DEFAULT_WARNING_MESSAGE_DELAY 2
#define DEFAULT_WARNING_MESSAGE_ENABLED TRUE

// actions
// default external commands
#define DEFAULT_LOCK_SCREEN_COMMAND "xlock"
#define DEFAULT_LOGOUT_COMMAND      ""
#define DEFAULT_REBOOT_COMMAND      "/sbin/reboot"
#define DEFAULT_SHUT_DOWN_COMMAND   "/sbin/poweroff"

// icons
#define SETTINGS_ICON_ACTIONS   "exit"
#define SETTINGS_ICON_GENERAL   "misc"
#define SETTINGS_ICON_LINKS     "run"
#define SETTINGS_ICON_SCHEDULER "kshutdown"
#define SETTINGS_ICON_SOUND     "knotify"

/** @short Settings dialog. */
class MSettingsDialog: public KDialogBase
{
	Q_OBJECT
public:

	// configuration

	KIntNumInput
		// general
		*warningMessageDelay;

	KURLRequester
		// sound
		*soundDir;

	QCheckBox
		// general
		*confirmAction,
		*popupMessages,
		*warningMessageEnabled,
		// sound
		*soundEnabled,
		// scheduler
		*schedulerEnabled;
		
	/**
	 * Constructor. Creates a new modal settings dialog.
	 * @param parent Parent widget
	 * @param name Widget name
	 */
	MSettingsDialog(QWidget *parent = 0, const char *name = 0);

	/** Destructor. */
	virtual ~MSettingsDialog();
	
	/** Returns a default KShutDown sound directory. */
	static QString getDefaultSoundDir();

	/** Sets warning message option to @p on, and its delay to @p delay. */
	void setWarningMessage(const bool on, const int delay);
	
	/** Shows page with name @p name. */
	void showPageByName(const QString &name);

private:
	int
		soundTest;
	KPushButton
		*b_lockScreenSettings,
		*b_logoutSettings;
	QFrame
		*actionsPage,
		*generalPage,
		*schedulerPage,
		*soundPage;
	QListView
		*actions;
	QListViewItem
		*lockScreenItem,
		*logoutItem,
		*rebootItem,
		*shutDownItem;
	
	/**
	 * Returns @c TRUE if page is disabled by the administrator (Kiosk).
	 * @param key Configuration entry (in kshutdownrc file)
	 * @param page Dialog page
	 * @param pageLayout Dialog page layout
	 */
	bool disabledByAdmin(const QString &key, QFrame *page = 0, QBoxLayout *pageLayout = 0) const;	
	
	void initActionsPage();
	void initGeneralPage();
	void initSchedulerPage();
	void initSoundPage();

	/**
	 * Changes action method.
	 * @param configEntry Configuration entry (in kshutdownrc file)
	 * @param method New method
	 * @param command New command
	 */
	void setMethod(const QString &configEntry, const MMainWindow::Method method, const QString &command) const;

	/** Updates all action items. */
	void updateActions();

	/** Updates action info in @p item. */
	void updateItem(QListViewItem *item);

private slots:
	void editActionSlot();
	void enableLockSettingsButtonSlot();
	void enableLogoutSettingsButtonSlot();
	void lockSettingsSlot();
	void logoutSettingsSlot();
	void popupMessagesTestSlot();
	void testSoundSlot();
	void toggleWarningMessageSlot(bool on);
	void updateWarningMessageSlot();
	void warningMessageTestSlot();
protected slots:
	virtual void slotDefault();
};

#endif // __MSETTINGSDIALOG_H__
