/*
	mstatstab.h - statistics tab
	Copyright (C) 2003  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __MSTATSTAB_H__
#define __MSTATSTAB_H__

#include <qcheckbox.h>
#include <qprocess.h>
#include <qtextedit.h>

#include <kpushbutton.h>

/** @short Statistics tab. It displays output from the `w' command. */
class MStatsTab: public QWidget
{
	Q_OBJECT
public:

	/**
	 * Constructor.
	 * @param parent Parent widget
	 * @param name Widget name
	 */
	MStatsTab(QWidget *parent = 0, const char *name = 0);
	
	/** Destructor. */
	virtual ~MStatsTab();
	
	/** Initializes widgets when user click on the "Scheduler" tab. */
	void initOnDemand();
	
	/** Returns @c TRUE if the `w' command has a long format; otherwise @c FALSE. */
	inline bool longFormat() const { return _longFormat; }
	
	/**
	 * Sets long/short format for the `w' command.
	 * @param yes If @c TRUE the long format is set
	 */
	void setLongFormat(const bool yes);

private:
	bool
		initDone,
		_longFormat;
	KPushButton
		*b_refresh;
	QCheckBox
		*c_longFormat;
	QProcess
		*process;
	QString
		buf;
	QTextEdit
		*te_output;
	void killProcess() const;
private slots:
	void longFormatCheckedSlot(bool check);
	void processExitSlot();
	void readStdoutSlot();
	void refreshSlot();
};

#endif // __MSTATSTAB_H__
