/*
	mtip.cpp - tip label
	Copyright (C) 2003  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "mtip.h"

#include <klocale.h>

/* constructor */

MTip::MTip(const TipType tipType, QWidget *parent, const char *name)
	: KActiveLabel(parent, name),
	// init
	_text(""),
	_type(TipType_Normal)
{
	setFrameStyle(Panel | Sunken);
	setMargin(4);
	setTipType(tipType);
	setTipText("");
}

/* destructor */

MTip::~MTip()
{
}

/* public */

QString MTip::getTipName() const
{
	switch (_type)
	{

		case TipType_Info:
			return i18n("Info:");

		case TipType_Normal:
			return i18n("Tip:");

		case TipType_Warning:
			return i18n("Warning:");

		default:
			return "";

	}
}

void MTip::setTipText(const QString &tipText)
{
	_text = tipText;
	setText("<qt><b>" + getTipName() + "</b> " + _text + "</qt>");
}

void MTip::setTipType(const TipType tipType)
{
	_type = tipType;
	switch (_type)
	{
		case TipType_Info:
			setPaletteBackgroundColor(QColor(255, 255, 255)); // white
			setPaletteForegroundColor(QColor(0, 0, 255)); // blue
			break;
		case TipType_Normal:
			setPaletteBackgroundColor(QColor(255, 255, 220)); // tool tip
			setPaletteForegroundColor(QColor(0, 0, 0)); // black
			break;
		case TipType_Warning:
			setPaletteBackgroundColor(QColor(255, 168, 88)); // light orange
			setPaletteForegroundColor(QColor(0, 0, 0)); // black
			break;
	}
}
