/*
	mwizard.cpp - wizard
	Copyright (C) 2004  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "mmainwindow.h"
#include "mradiobutton.h"
#include "mwizard.h"

#include <qlayout.h>
#include <qpushbutton.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

#include <kiconloader.h>
#include <klocale.h>

/* constructor */

MWizard::MWizard(QWidget *parent, const char *name)
	: KWizard(parent, name, TRUE)
{
	setCaption(i18n("Wizard"));

// TODO: help
	helpButton()->hide();

	initActionPage();
	initTimePage();

	connect(
		this, SIGNAL(selected(const QString&)),
		this, SLOT(pageSelectedSlot(const QString&)));
}

/* destructor */

MWizard::~MWizard()
{
}

/* public */

bool MWizard::runWizard()
{
// FIXME: KDialog::centerOnScreen(this);
	if (exec() == QDialog::Accepted)
	{
		mainWindow->cancelAction(); // cancel action before "setWhen"

		MMainWindow::What action = getSelectedAction();

		if (action == MMainWindow::What_Nothing)
			return FALSE;

		if (rb_now->isChecked())
		{
			mainWindow->setWhen(MMainWindow::When_Now);
		}
		else if (rb_atDateTime->isChecked())
		{
			mainWindow->setWhen(MMainWindow::When_DateTime);
			mainWindow->setDate(dateEdit->date());
			mainWindow->setTime(timeEdit->time());
		}
		else if (rb_timeFromNow->isChecked())
		{
			mainWindow->setWhen(MMainWindow::When_DelayTime);
			mainWindow->setTime(timeEdit->time());
		}

		mainWindow->setActive(action, TRUE);

		return TRUE;
	}

	return FALSE;
}

/* private */

QString MWizard::formatDateTime(const QDateTime &dt) const {
	QString s = dt.toString("hh:mm, dddd") + " (+";

	QDateTime now(QDate::currentDate(), QTime::currentTime());
	int secs = now.secsTo(dt);

	if (secs >= 86400 || secs < 0)
	{
		s += ">24";
	}
	else
	{
		int h = secs / 3600;
		int m = (secs / 60) % 60;
		QTime t(h, m, 0);
		s += t.toString("hh:mm");
	}

	return s + ")";
}

MMainWindow::What MWizard::getSelectedAction()
{
	if (rb_logout->isChecked())
		return MMainWindow::What_Logout;

	if (rb_shutDown->isChecked())
		return MMainWindow::What_ShutDown;

	if (rb_reboot->isChecked())
		return MMainWindow::What_Reboot;

	return MMainWindow::What_Nothing;
}

QString MWizard::getStepName(const int current)
{
	QString s = QString(i18n("Step %1 of %2"))
		.arg(current)
		.arg(2);

	return s;
}

void MWizard::initActionPage()
{
	QWidget *mw = new QWidget(this);
	QHBoxLayout *ml = new QHBoxLayout(mw);

	QWidget *w = new QWidget(mw);
	QVBoxLayout *l = new QVBoxLayout(w);
	bg_actions = new QVButtonGroup(i18n("What do you want to do?"), w);

	rb_logout = new MRadioButton(i18n("&End session only"), bg_actions);
	rb_logout->setChecked(TRUE);
	connect(
		rb_logout, SIGNAL(doubleClicked()),
		this, SLOT(next()));
	rb_shutDown = new MRadioButton(i18n("&Turn off computer"), bg_actions);
	connect(
		rb_shutDown, SIGNAL(doubleClicked()),
		this, SLOT(next()));
	rb_reboot = new MRadioButton(i18n("&Restart computer"), bg_actions);
	connect(
		rb_reboot, SIGNAL(doubleClicked()),
		this, SLOT(next()));

	l->addWidget(bg_actions);

	// zzz konq
	QLabel *konq = new QLabel(mw, "QLabel::konq");
	konq->setAlignment(AlignCenter);
	konq->setPixmap(UserIcon("zzzkonq.png"));
	ml->addWidget(konq);
	// radio buttons
	ml->addWidget(w);

	addPage(mw, getStepName(1));
}

void MWizard::initTimePage()
{
	timePage = new QWidget(this);
	QVBoxLayout *ml = new QVBoxLayout(timePage);

	// radio buttons + date/time editors layout
	QWidget *ww = new QWidget(timePage, "QWidget::ww");
	QHBoxLayout *wl = new QHBoxLayout(ww);

	// radio buttons
	QVButtonGroup *bg_when = new QVButtonGroup(i18n("When to run the selected action?"), ww);
	connect(
		bg_when, SIGNAL(clicked(int)),
		this, SLOT(whenClickedSlot(int)));

	rb_now = new QRadioButton(i18n("&Now (no delay)"), bg_when);
	rb_now->setChecked(TRUE);

	rb_atDateTime = new QRadioButton(i18n("At &date/time"), bg_when);

	rb_timeFromNow = new QRadioButton(i18n("&Time from now"), bg_when);

	wl->addWidget(bg_when);

	// date/time editors
	QWidget *editWidget = new QWidget(ww, "QWidget::editWidget");
	QVBoxLayout *editLayout = new QVBoxLayout(editWidget);

	timeEdit = new QTimeEdit(editWidget, "QTimeEdit::timeEdit");
	timeEdit->setDisplay(QTimeEdit::Hours | QTimeEdit::Minutes);
	QToolTip::add(timeEdit, i18n("HH:MM"));
	QWhatsThis::add(timeEdit, i18n("HH:MM"));
	editLayout->addWidget(timeEdit);
	connect(
		timeEdit, SIGNAL(valueChanged(const QTime&)),
		this, SLOT(timeEditValueChangedSlot(const QTime&)));
	wl->addWidget(editWidget);

	dateEdit = new QDateEdit(QDate::currentDate(), editWidget, "QDateEdit::dateEdit");
	connect(
		dateEdit, SIGNAL(valueChanged(const QDate&)),
		this, SLOT(dateEditValueChangedSlot(const QDate&)));
	editLayout->addWidget(dateEdit);

	ml->addWidget(ww);

#if 0
	QLabel *l_finish = new QLabel(
		i18n("Click <b>Finish</b> button to activate the selected action."),
		timePage, "QLabel::l_finish");
	ml->addWidget(l_finish);
#endif


	l_action = new QLabel(timePage, "QLabel::l_action");
	l_action->setText("null"); // set in "pageSelectedSlot()"
	ml->addWidget(l_action);

	l_time = new QLabel(timePage, "QLabel::l_time");
	ml->addWidget(l_time);

	addPage(timePage, getStepName(2));
	setFinishEnabled(timePage, TRUE);

	updateTimeInfo();
	updateTimeWidgets();
}

void MWizard::updateTimeInfo()
{
	QString s_timeHint;
	if (rb_now->isChecked())
	{
		s_timeHint = i18n("No delay");
	}
	else if (rb_atDateTime->isChecked())
	{
		QDateTime dt(dateEdit->date(), timeEdit->time());
		s_timeHint = formatDateTime(dt);
	}
	else if (rb_timeFromNow->isChecked())
	{
		QDateTime dt(QDate::currentDate(), QTime::currentTime());
		s_timeHint = formatDateTime(
			dt.addSecs(
				(timeEdit->time().hour() * 3600) +
				timeEdit->time().minute() * 60
			)
		);
	}

	QString s = QString(i18n("Selected time:") + " <b>%1</b>").arg(s_timeHint);
	l_time->setText(s);
}

void MWizard::updateTimeWidgets()
{
	if (rb_now->isChecked())
	{
		dateEdit->setEnabled(FALSE);
		timeEdit->setEnabled(FALSE);
	}
	else if (rb_atDateTime->isChecked())
	{
		dateEdit->setDate(QDate::currentDate());
		dateEdit->setEnabled(TRUE);
		timeEdit->setTime(QTime::currentTime());
		timeEdit->setEnabled(TRUE);
	}
	else if (rb_timeFromNow->isChecked())
	{
		dateEdit->setDate(QDate::currentDate());
		dateEdit->setEnabled(FALSE);
		timeEdit->setTime(QTime(0, 0, 0));
		timeEdit->setEnabled(TRUE);
	}
}

/* private slots */

void MWizard::dateEditValueChangedSlot(const QDate &/*date*/)
{
	updateTimeInfo();
}

void MWizard::pageSelectedSlot(const QString &selectedTitle)
{
	if (selectedTitle == title(timePage)) // time page selected
	{
		// setup "finish" icon
		MMainWindow::What action = getSelectedAction();
		finishButton()->setIconSet(mainWindow->getActionIcon(action));
		finishButton()->setText(mainWindow->getActionName(action));

		// update selected action info
		QButton *b_selectedAction = bg_actions->selected();
		if (b_selectedAction)
		{
			QString s_actionName = b_selectedAction->text();
			s_actionName.remove("&");
			QString s_actionHint =
				QString(i18n("Selected action:") + " <b>%1</b>")
					.arg(s_actionName);
			l_action->setText(s_actionHint); // update selected action name
		}
	}
}

void MWizard::timeEditValueChangedSlot(const QTime &/*time*/)
{
	updateTimeInfo();
}

void MWizard::whenClickedSlot(int /*id*/)
{
	updateTimeInfo();
	updateTimeWidgets();
}
