/*
	mwizard.h - wizard
	Copyright (C) 2004  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __MWIZARD_H__
#define __MWIZARD_H__

#include "mmainwindow.h"

#include <qdatetimeedit.h>
#include <qlabel.h>
#include <qradiobutton.h>
#include <qvbuttongroup.h>

#include <kwizard.h>

class MRadioButton;

/** @short Wizard dialog. Used in @c MMainWindow::wizardSlot(). */
class MWizard: public KWizard
{
	Q_OBJECT
public:
	/**
	 * Constructor.
	 * @param parent Parent widget.
	 * @param name Widget name.
	 */
	MWizard(QWidget *parent = 0, const char *name = 0);

	/** Destructor. */
	~MWizard();

	/**
	 * Launches the Wizard dialog, and executes selected action.
	 * @return @c TRUE if successfull; otherwise @c FALSE
	 */
	bool runWizard();
private:
	MRadioButton
		*rb_logout,
		*rb_shutDown,
		*rb_reboot;
	QDateEdit
		*dateEdit;
	QLabel
		*l_action,
		*l_time;
	QRadioButton
		*rb_now,
		*rb_atDateTime,
		*rb_timeFromNow;
	QTimeEdit
		*timeEdit;
	QVButtonGroup
		*bg_actions;
	QWidget
		*timePage;
	QString formatDateTime(const QDateTime &dt) const;
	MMainWindow::What getSelectedAction();
	QString getStepName(const int current);
	void initActionPage();
	void initTimePage();
	void updateTimeInfo();
	void updateTimeWidgets();
private slots:
	void dateEditValueChangedSlot(const QDate &date);
	void pageSelectedSlot(const QString &selectedTitle);
	void timeEditValueChangedSlot(const QTime &time);
	void whenClickedSlot(int id);
};

#endif // __MWIZARD_H__
